export declare type ICallback<ResponseType, Args> = (response: ResponseType, args: Args) => any;
export declare type ICallFn<Args> = (args: Args) => Promise<any>;
export interface IUseAsyncRequestProps<ResponseType, Args> {
    args: Args;
    callFn: ICallFn<Args>;
    cleanupFunc?: () => void;
    callOnInit?: boolean;
    debug?: boolean;
    callback?: ICallback<ResponseType, Args>;
    errorCallback?: (AsyncRequestError: any) => void;
}
export interface IFnArgs<ResponseType, Args> {
    args: Args;
    callback: ICallback<ResponseType, Args>;
}
/**
 * Async React request hook
 *
 * @param {Object} {
 *   - args {Array} - the arguments to be passed to the callFn,
 *   - callFn {function} - the async function to call
 *   - cleanupFunc {function} - function to clean up the async call
 *   - callOnInit {bool}(true) - if true then will call the function on component mount
 *   - callback {function} - function to call when async call returns (response, args) => {}
 * }
 * @return {Object} {
 *   - response {any} - the response from the async call
 *   - reload {function} - function to recall the call function
 *   - call {function} - same as reload
 *   - loading {bool} - true when callfn has been called but not yet returned
 *   - hasLoaded {bool} - true after the callFn has been ran at least once
 *   - error {string} - error returned by callfn
 * }
 */
export declare const useAsyncRequest: {
    <ResponseType_1, Args extends any[]>({ args: argsInitial, callFn, cleanupFunc, callOnInit, debug, callback: callbackIn, errorCallback: errorCallbackIn, }: IUseAsyncRequestProps<ResponseType_1, Args>): {
        resultState: {
            isLoading: boolean;
            latestLoadingId: number;
            resultsData: any;
            hasLoaded: boolean;
            error: any;
            callCount: number;
        };
        response: any;
        reload: (argsUpdated: Args, callbackOverride?: ICallback<ResponseType_1, Args>) => void;
        call: (argsUpdated: Args, callbackOverride?: ICallback<ResponseType_1, Args>) => void;
        loading: boolean;
        hasLoaded: boolean;
        error: any;
        callCount: number;
    };
    propTypes: {
        args: any;
        callFn: any;
        cleanupFunc: any;
        callOnInit: any;
        debug: any;
        callback: any;
    };
};
